@@ -1,7 +1,6 @@
+# frozen_string_literal: true
+
 module Babosa
-  def self.jruby15?
-    JRUBY_VERSION >= "1.5" rescue false
-  end
 end
 
 class String
@@ -12,5 +11,4 @@ class String
 end
 
 require "babosa/transliterator/base"
-require "babosa/utf8/proxy"
 require "babosa/identifier"
