@@ -1,4 +1,5 @@
-# encoding: utf-8
+# frozen_string_literal: true
+
 module Babosa
   module Transliterator
     class Bulgarian < Cyrillic
@@ -21,7 +22,7 @@ module Babosa
         "ь" => "i",
         "ю" => "iu",
         "я" => "ia"
-      }
+      }.freeze
     end
   end
 end
