@@ -1,4 +1,5 @@
-# encoding: utf-8
+# frozen_string_literal: true
+
 module Babosa
   module Transliterator
     class German < Latin
@@ -9,7 +10,7 @@ module Babosa
         "Ä" => "Ae",
         "Ö" => "Oe",
         "Ü" => "Ue"
-      }
+      }.freeze
     end
   end
 end
