@@ -1,4 +1,5 @@
-# encoding: utf-8
+# frozen_string_literal: true
+
 module Babosa
   module Transliterator
     class Norwegian < Latin
@@ -7,8 +8,7 @@ module Babosa
         "å" => "aa",
         "Ø" => "Oe",
         "Å" => "Aa"
-      }
+      }.freeze
     end
   end
 end
-
