@@ -1,9 +1,9 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 module Babosa
   module Transliterator
     class Spanish < Latin
-      APPROXIMATIONS = {"ñ" => "ni", "Ñ" => "Ni"}
+      APPROXIMATIONS = {"ñ" => "ni", "Ñ" => "Ni"}.freeze
     end
   end
 end
