@@ -1,4 +1,5 @@
-# encoding: utf-8
+# frozen_string_literal: true
+
 module Babosa
   module Transliterator
     class Swedish < Latin
@@ -9,8 +10,7 @@ module Babosa
         "Å" => "Aa",
         "Ä" => "Ae",
         "Ö" => "Oe"
-      }
+      }.freeze
     end
   end
 end
-
