@@ -1,12 +1,12 @@
-# coding: utf-8
+# frozen_string_literal: true
 
-if ENV['COV']
-  require 'simplecov'
+if ENV["COV"]
+  require "simplecov"
   SimpleCov.start
 end
 
-require 'bundler/setup'
-require 'babosa'
+require "bundler/setup"
+require "babosa"
 
 shared_examples_for "a latin transliterator" do
   let(:t) { described_class.instance }
@@ -42,4 +42,4 @@ shared_examples_for "a hindi transliterator" do
     string = "आदित्य तापड़िया"
     expect(t.transliterate(string)).to match(/[\x0-\x7f]/)
   end
-end
\ No newline at end of file
+end
