@@ -1,8 +1,8 @@
-# encoding: utf-8
-require File.expand_path("../../spec_helper", __FILE__)
+# frozen_string_literal: true
+
+require "spec_helper"
 
 describe Babosa::Transliterator::German do
-
   let(:t) { described_class.instance }
   it_behaves_like "a latin transliterator"
 
@@ -13,5 +13,4 @@ describe Babosa::Transliterator::German do
   it "should transliterate vowels with umlauts" do
     expect(t.transliterate("üöä")).to eql("ueoeae")
   end
-
-end
\ No newline at end of file
+end
