@@ -1,13 +1,12 @@
-# encoding: utf-8
-require File.expand_path("../../spec_helper", __FILE__)
+# frozen_string_literal: true
+
+require "spec_helper"
 
 describe Babosa::Transliterator::Spanish do
-
   let(:t) { described_class.instance }
   it_behaves_like "a latin transliterator"
 
   it "should transliterate ñ" do
     expect(t.transliterate("ñ")).to eql("ni")
   end
-
-end
\ No newline at end of file
+end
